#### Plant expansion drives bacteria and collembola communities under winter climate change in frost-affected tundra ####
################ E.J. Krab, S. Monteux, J.T. Weedon, E. Dorrepaal - 2019 - Soil Biology and Biochemistry ################
# doi: https://dx.doi.org/10.1016/j.soilbio.2019.107569 
# figshare: https://dx.doi.org/10.6084/m9.figshare.9730760
# 2019-08-27 - R version 3.4.4 x86_64-pc-linux-gnu (64-bit)

# Welcome!
# Before starting, please make sure the folder structure is as follows and you have all data files:
# wd: SBB_NSC_script.R , Data/
    # /Data/:
    # - global_wunifrac2000_clean.txt
    # - global2000_alphadiv.txt
    # - global2000_ggtax_L2.txt
    # - Mapping_NSC.csv
    # - NSC_count_and_met.csv
    # - NSC_richness.csv
    # - snow_depth_20130326.csv , snow_depth_20140403.csv , snow_depth_20140429.csv
    # - wunifrac_deep.txt
    # - wunifrac_surf.txt

# For questions regarding the article and analyses please contact the corresponding author eveline.krab@slu.se
# For questions or troubleshooting regarding the figshare repository, R script or jupyter notebook, please contact sylvain.monteux@slu.se (or monteux@pm.me)


#### Summary
# 0. Working directory, libraries, data files
# 1. Figure 1: NMDS ordination plots of collembola species composition and bacteria OTUs composition in non-sorted circles.
# 2. Figure 2: Average relative abundance of collembola species and bacterial phyla in three sampling domains of non-sorted circles and for the three different winter warming treatments.
# 3. Figure 3: NMDS ordination plots of collembola species composition and bacteria OTUs in non-sorted circles.
# 4. Figure 4: Effects of winter warming treatments on soil properties in three sampling domains of non-sorted circles and the corresponding vegetation cover.
# 5. Supplementary Figure S2
# Please note that Supplementary Figure S3 is not presented here, see Krab et al. 2018, Journal of Ecology.  https://doi.org/10.1111/1365-2745.12872 
# 6. Supplementary Figure S4
# 7. Supplementary Figure S5

#### 0. Working directory, libraries, data files ----
library(vegan)
library(car)
library(nlme)
library(ggplot2)
library(scales)
library(RColorBrewer)
library(dplyr)
library(reshape2)
library(gridExtra)
library(plyr)
library(sciplot) 

setwd("") # Set to your convenience

## import Collembola counts and metadata file
alldata<-read.csv("Data/NSC_count_and_met.csv")
colnames(alldata)[26]<- "soil.moisture"
colnames(alldata)[27]<- "bulk"
colnames(alldata)[28]<- "som"
colnames(alldata)[29]<- "veg.cover"
colnames(alldata)[30]<- "pH"
# Run NMDS for collembola analyses
nmdsdata<-alldata[,c(8:23)]
factordata <- alldata[,c(1:6)]
NMDSalldata <- metaMDS(nmdsdata, zerodist="add", trymax=1000) 
nmds.fit3<-envfit(NMDSalldata ~ bulk+som+soil.moisture+veg.cover+pH, data=alldata, permu=999,strata=alldata$sampling.point)
nmds.fit3


## import bacteria unifrac distance matrix and compute NMDS
dist<-as.dist(read.delim("Data/global_wunifrac2000_clean.txt",row.names=1))
mds1<-metaMDS(dist,distance="wunifrac",trymax=1000)

# import subsetted matrixes for Surface and Deep samples only
dist_deep<-as.dist(read.delim("Data/wunifrac_deep.txt",row.names=1))
dist_surf<-as.dist(read.delim("Data/wunifrac_surf.txt",row.names=1))
mdsdeep<-metaMDS(dist_deep,distance="wunifrac",trymax=1000)
mdssurf<-metaMDS(dist_surf,distance="wunifrac",trymax=1000)

## import bacteria taxa summary tables (phylum level)
phyla<-read.table("Data/global2000_ggtax_L2.txt",header=T,row.names=1)

## import metadata file used for bacteria - Note that metadata is duplicated: 
# the same values are used for the Surface and Deep samples taken in a given location within a plot
primers<-read.csv("Data/Mapping_NSC.csv")
rownames(primers)<-primers$SampleID
primers<-subset(primers,primers$Xname %in% rownames(mds1$points))
all.equal(rownames(mds1$points),rownames(primers))
# the order of the samples in the MDS is not the same as in the metadata file
# match metadata with distance matrix samples
matchedprimers<-primers[match(rownames(mds1$points),(primers$Xname)),]
row.names(matchedprimers)<-matchedprimers$Xname
all.equal(rownames(mds1$points),rownames(matchedprimers))

# Import alpha diversity metrics for Collembola
alpha<-read.csv("Data/NSC_richness.csv")

# Import alpha diversity metrics for bacteria
alpha_div<-read.table("Data/global2000_alphadiv.txt")
Metadata_div<-primers[match(rownames(alpha_div),rownames(primers)),]
all.equal(rownames(alpha_div),rownames(Metadata_div))

# Import snow depth data (Supplementary Figure S2)
snow2013 <- read.csv("Data/snow_depth_20130326.csv")
snow2014_1 <- read.csv("Data/snow_depth_20140403.csv")
snow2014_2 <- read.csv("Data/snow_depth_20140429.csv")



#### 1. Figure 1 ####
#### Figure 1a ----
figellipse <- ordiplot(NMDSalldata,display="sites",cex.axis=1.3,cex.lab=1.5,type="none")
ordiellipse(figellipse,groups=alldata$treatment, kind="se", conf=0.95, lwd=2, show.groups="fleece", col="black",lty=5)
ordiellipse(figellipse,groups=alldata$treatment, kind="se",conf=0.95, lwd=2, show.groups="control", col="black")
ordiellipse(figellipse,groups=alldata$treatment, kind="se",lwd=2,conf=0.95, show.groups="snow", col="black", lty=3)
ordiellipse(figellipse,groups=alldata$sampling.point,kind="se", conf=0.95,lwd=3, show.groups="IDNV", col="blue")
ordiellipse(figellipse,groups=alldata$sampling.point,kind="se", conf=0.95,lwd=3, show.groups="IDV", col="forestgreen")
ordiellipse(figellipse,groups=alldata$sampling.point,kind="se", conf=0.95, lwd=3, show.groups="OD", col="red")
points(NMDSalldata, display="sites",pch= c(16,15,17)[as.numeric(alldata$treatment)],col=c("blue","forestgreen","red")[as.numeric(alldata$sampling.point)], cex=1.3)
legend("bottomleft",box.col=NA,lty=c(1,5,3,NA,1,1,1),pch=c(16,15,17,16,16,16,16),col=c("black","black","black",NA,"blue","forestgreen","red"),lwd=2,seg.len=3,legend=c("Control","Fleece","Snow",NA,"Inner domain bare","Inner domain vegetated","Outer domain"))

#### Figure 1b ----
fig1<-ordiplot(mds1,cex.axis=1.3,cex.lab=1.5)
points(mds1,pch=c(16,17,15)[matchedprimers$Treatment],cex=1.3,col=c("blue","forestgreen","red")[matchedprimers$Location])
ordiellipse(fig1,groups=matchedprimers$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Fleece",col="black",lty=5)
ordiellipse(fig1,groups=matchedprimers$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Control",col="black")
ordiellipse(fig1,groups=matchedprimers$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Snowfence",col="black",lty=3)
ordiellipse(fig1,groups=matchedprimers$Location,kind="se", conf=0.95,lwd=3,show.groups="IN",col="blue")
ordiellipse(fig1,groups=matchedprimers$Location,kind="se", conf=0.95,lwd=3,show.groups="IV",col="forestgreen")
ordiellipse(fig1,groups=matchedprimers$Location,kind="se", conf=0.95,lwd=3,show.groups="O",col="red")



#### 2. Figure 2 ----
### Figure 2a ----
### subset data for creating data frame with abundances as list
barplot<-alldata[,c(8:24)]
colnames(barplot[-c(1:4)])
barplot$id = rownames(barplot)
Unknowns<-rowSums(barplot[,c(8:17)])
unkn<-data.frame(Unknowns)
domspec<-subset(barplot,select=c(1:7))
subset<-cbind(domspec,unkn)
subset$id = rownames(subset)

community<-melt(subset)
variable<-alldata[,c(1,3:5)]

stackedplot<-cbind(variable,community)
colnames(stackedplot)[6]<- "Species"
colnames(stackedplot)[7]<- "Abundance"
colnames(stackedplot[3])<- "Treatment"

### calculate means per treatment and sampling point
graph<-aggregate(Abundance~treatment+sampling.point+Species, mean, data=stackedplot)

## Relabeling
graph$Species <- as.character(graph$Species)
graph$Species[graph$Species=="fol_qua"] <- "Folsomia quadrioculata"
graph$Species[graph$Species=="tet_arc"] <- "Tetracanthella wahlgreni"
graph$Species[graph$Species=="iso_vir"] <- "Isotoma viridis"
graph$Species[graph$Species=="pro_pse"] <- "Protaphorura pseudovdd."
graph$Species[graph$Species=="fri_tru"] <- "Friesea truncata"
graph$Species[graph$Species=="cer_den"] <- "Ceratophysella denticulata"
graph$Species[graph$Species=="iso_min"] <- "Isotomiella minor"
graph$Species[graph$Species=="Unknowns"] <- "Other"
graph$Species <- as.factor(graph$Species)

graph$sampling.point <- as.character(graph$sampling.point)
graph$sampling.point[graph$sampling.point=="IDNV"] <- "Inner domain bare"
graph$sampling.point[graph$sampling.point=="IDV"] <- "Inner domain vegetated"
graph$sampling.point[graph$sampling.point=="OD"] <- "Outer domain"
graph$sampling.point <- as.factor(graph$sampling.point)

graph$treatment <- as.character(graph$treatment)
graph$treatment[graph$treatment=="control"] <- "Control"
graph$treatment[graph$treatment=="fleece"] <- "Fleece"
graph$treatment[graph$treatment=="snow"] <- "Snow"
graph$treatment <- as.factor(graph$treatment)

graph <- transform(graph, Species=factor(Species, levels=unique(Species)))

bargraph <- ggplot(graph,aes(x = treatment, y = Abundance,fill = Species)) + 
  geom_bar(position = "fill",stat = "identity") + facet_grid(~sampling.point)+
  #scale_fill_grey(start=0.3,end=0.9)+
  scale_fill_brewer(type="qual",palette=3)+
  scale_y_continuous(labels = percent_format())+
  theme(panel.background=element_blank(),
        strip.text.x=element_text(size=12),
        strip.background=element_blank(),
        axis.text.y=element_text(size=14, color="black"),
        axis.text.x=element_text(size=14, color="black", angle=90,hjust=1.0),
        panel.border=element_blank(), 
        panel.grid=element_blank(),
        axis.line = element_line(),
        axis.title.y=element_text(size=14,color="black", vjust=1.5),
        axis.title.x=element_text(size=14,color="black", vjust=-0.8),
        legend.background = element_blank(),
        legend.text=element_text(size=14,face=3),
        legend.title=element_blank(),
        legend.key=element_blank())+
  xlab("Treatment")+ylab("Relative Abundance")+
  guides(fill=guide_legend(reverse=F))
plot(bargraph)

#### Figure 2b ----
tax2top12<-phyla[rowSums(phyla)>0.6,]
tax2other<-phyla[-c(which(rownames(phyla) %in% rownames(tax2top12))),]
# add Other
tax2top12['Other',]<-colSums(tax2other)
row.names(tax2top12)<-gsub("k__Bacteria;","",gsub("k__.*p__", "", rownames(tax2top12)))

tax2top12$phyla = rownames(tax2top12)
communitymicrobe<-melt(tax2top12)
colnames(communitymicrobe)[2]<-"SampleID"
variable2<-matchedprimers[,c(1,6:8)]
new <- right_join(variable2,communitymicrobe,by="SampleID")

### Calculate averages relative abundance per treatment and sampling location.
graph2<-aggregate(value~Treatment+Location+phyla, mean, data=new)

# specify factors in dataframe and rename some locations for representation in the graph
graph2$phyla <- as.factor(graph2$phyla)
graph2$Location <- as.character(graph2$Location)
graph2$Location[graph2$Location=="IN"] <- "Inner domain bare"
graph2$Location[graph2$Location=="IV"] <- "Inner domain vegetated"
graph2$Location[graph2$Location=="O"] <- "Outer domain"
graph2$Location <- as.factor(graph2$Location)
graph2$Treatment <- as.character(graph2$Treatment)
graph2$Treatment[graph2$Treatment=="Snowfence"] <- "Snow"
graph2$Treatment <- as.factor(graph2$Treatment)
#set phyla as factors (for stacking?)
# graph2 <- transform(graph2, phyla=factor(phyla, levels=unique(phyla)))



# Here is an alternative with colors so its easier to tell who is who
graph2$Phyla<-factor(graph2$phyla,levels=c("Acidobacteria","Actinobacteria","AD3","Armatimonadetes","Bacteroidetes","Chloroflexi","Cyanobacteria","Gemmatimonadetes","Planctomycetes","Proteobacteria","Verrucomicrobia","WPS-2","Other"))
pal2<-c(brewer.pal(12,"Paired"),"#bdbdbd")
graph2_2<-arrange(graph2,desc=Phyla)

bargraph3<-ggplot(graph2_2, aes(x = Treatment))+
  theme_bw() +  
  facet_grid(~Location)+
  geom_bar(aes(weight=value, fill = Phyla), position = 'fill') + 
  scale_y_continuous(labels = percent_format())+
  theme(panel.background=element_blank(),
        strip.text.x=element_text(size=12),
        strip.background=element_blank(),
        axis.text.y=element_text(size=14, color="black"),
        axis.text.x=element_text(size=14, color="black", angle=90,hjust=1.0),
        panel.border=element_blank(), 
        panel.grid=element_blank(),
        axis.line = element_line(),
        axis.title.y=element_text(size=14,color="black", vjust=1.5),
        axis.title.x=element_text(size=14,color="black", vjust=-0.8),
        legend.background = element_blank(),
        legend.text=element_text(size=14,face=3),
        legend.title=element_blank(),
        legend.key=element_blank())+
  scale_fill_manual(values=(pal2),guide=guide_legend(reverse=F)) + 
  #scale_fill_grey(start=0.3,end=0.9,guide=guide_legend(reverse=TRUE))+
  xlab("Treatment")+ylab("Relative Abundance")

bargraph3

#### Two panel graph Collembola and microbes ----
panelplot<-grid.arrange(bargraph,bargraph3,ncol=2)
#To be able to use ggsave
g<-arrangeGrob(bargraph,bargraph3,ncol=2)
ggsave("Figure_2.pdf",dpi=600,width=46,height=15,unit="cm",g)


#### 3. Figure 3 ----
### Figure 3a ----
figellipse <- ordiplot(NMDSalldata,display="sites",cex.axis=1.3,cex.lab=1.5,type="none")
ordiellipse(figellipse,groups=alldata$treatment, kind="se", conf=0.95, lwd=2, show.groups="fleece", col="grey25",lty=5)
ordiellipse(figellipse,groups=alldata$treatment, kind="se",conf=0.95, lwd=2, show.groups="control", col="grey25")
ordiellipse(figellipse,groups=alldata$treatment, kind="se",lwd=2,conf=0.95, show.groups="snow", col="grey25", lty=3)
ordiellipse(figellipse,groups=alldata$sampling.point,kind="se", conf=0.95,lwd=2, show.groups="IDNV", col="blue")
ordiellipse(figellipse,groups=alldata$sampling.point,kind="se", conf=0.95,lwd=2, show.groups="IDV", col="forestgreen")
ordiellipse(figellipse,groups=alldata$sampling.point,kind="se", conf=0.95, lwd=2, show.groups="OD", col="red")
points(NMDSalldata, display="sites", cex=-1, col="white")
legend("bottomleft",lty=c(1,5,3,NA,1,1,1),cex=0.9,col=c("grey25","grey25","grey25",NA,"blue","forestgreen","red"),lwd=2,seg.len=3,legend=c("Control","Fleece","Snow",NA,"Inner domain bare","Inner domain vegetated","Outer domain"))

## Fix names in subset
taxainf <- cbind(factordata,subset)
colnames(taxainf)[c(7:14)]<-c("Folsomia","Tetracanthella","Isotoma","Protaphorura","Friesea","Ceratophysella","Isotomiella","Unknowns")
nmds.fit4<-envfit(NMDSalldata,taxainf[,c(7:14)], data=taxainf, permu=999,strata=taxainf$sampling.point)
plot(nmds.fit4, col="black")

# ### now same figure no labels
# ### NMDS plot with arrows for Collembola species
# figellipse <- ordiplot(NMDSalldata,display="sites",cex.axis=1.3,cex.lab=1.5,type="none")
# ordiellipse(figellipse,groups=alldata$treatment, kind="se", conf=0.95, lwd=2, show.groups="fleece", col="grey25",lty=5)
# ordiellipse(figellipse,groups=alldata$treatment, kind="se",conf=0.95, lwd=2, show.groups="control", col="grey25")
# ordiellipse(figellipse,groups=alldata$treatment, kind="se",lwd=2,conf=0.95, show.groups="snow", col="grey25", lty=3)
# ordiellipse(figellipse,groups=alldata$sampling.point,kind="se", conf=0.95,lwd=2, show.groups="IDNV", col="blue")
# ordiellipse(figellipse,groups=alldata$sampling.point,kind="se", conf=0.95,lwd=2, show.groups="IDV", col="forestgreen")
# ordiellipse(figellipse,groups=alldata$sampling.point,kind="se", conf=0.95, lwd=2, show.groups="OD", col="red")
# points(NMDSalldata, display="sites", cex=-1, col="white")
# #legend("bottomleft",lty=c(1,5,3,NA,1,1,1),cex=0.9,col=c("grey25","grey25","grey25",NA,"blue","forestgreen","red"),lwd=2,seg.len=3,legend=c("Control","Fleece","Snow",NA,"Inner domain bare","Inner domain vegetated","Outer domain"))
# 
# ## Fix names in subset
# taxainf <- cbind(factordata,subset)
# nmds.fit4<-envfit(NMDSalldata,taxainf[,c(7:14)], data=taxainf, permu=999,strata=taxainf$sampling.point)
# plot(nmds.fit4, col="black", label=T)
# nmds.fit4







#### Figure 3b ----
fittax2<-envfit(mds1$points,t(tax2top12[,-86]))
fittax2

fig1<-ordiplot(mds1,display = "sites",cex.axis=1.3,cex.lab=1.5,type="none")
ordiellipse(fig1,groups=matchedprimers$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Fleece",col="grey25",lty=5)
ordiellipse(fig1,groups=matchedprimers$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Control",col="grey25")
ordiellipse(fig1,groups=matchedprimers$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Snowfence",col="grey25",lty=3)
ordiellipse(fig1,groups=matchedprimers$Location,kind="se", conf=0.95,lwd=2,show.groups="IN",col="blue")
ordiellipse(fig1,groups=matchedprimers$Location,kind="se", conf=0.95,lwd=2,show.groups="IV",col="forestgreen")
ordiellipse(fig1,groups=matchedprimers$Location,kind="se", conf=0.95,lwd=2,show.groups="O",col="red")
#points(mds1,pch=c(15,17,16)[matchedprimers$Treatment],col=c("blue","forestgreen","red")[matchedprimers$Location])
plot(fittax2,col="black",p.max=0.05)



#### Figure 3c ----
figellipse <- ordiplot(NMDSalldata,display="sites",cex.axis=1.3,cex.lab=1.5,type="none")
ordiellipse(figellipse,groups=alldata$treatment, kind="se", conf=0.95, lwd=2, show.groups="fleece", col="grey25",lty=5)
ordiellipse(figellipse,groups=alldata$treatment, kind="se",conf=0.95, lwd=2, show.groups="control", col="grey25")
ordiellipse(figellipse,groups=alldata$treatment, kind="se",lwd=2,conf=0.95, show.groups="snow", col="grey25", lty=3)
ordiellipse(figellipse,groups=alldata$sampling.point,kind="se", conf=0.95,lwd=2, show.groups="IDNV", col="blue")
ordiellipse(figellipse,groups=alldata$sampling.point,kind="se", conf=0.95,lwd=2, show.groups="IDV", col="forestgreen")
ordiellipse(figellipse,groups=alldata$sampling.point,kind="se", conf=0.95, lwd=2, show.groups="OD", col="red")
# points(NMDSalldata, display="sites", cex=-1, col="white")
## paste arrows in this figure (remove label command for names)
plot(nmds.fit3, col="black")
# make legend
legend("bottomleft",bty="n",box.col=NA,lty=c(1,5,3,NA,1,1,1),cex=1,col=c("grey25","grey25","grey25",NA,"blue","forestgreen","red"),lwd=2,seg.len=3,legend=c("Control","Fleece","Snow",NA,"Inner domain bare","Inner domain vegetated","Outer domain"),border=F)


#### Figure 3d ----
envdat<-cbind(matchedprimers[,c(1,6:9,10,15:20)])
fitmds<-envfit(mds1,envdat[,6:10])
fitmds

fig1<-ordiplot(mds1,display = "sites",cex.axis=1.3,cex.lab=1.5,type="none")
#points(mds1,pch=c(15,17,NA,16)[matchedprimers$Treatment],col=c(NA,"blue","forestgreen","red")[matchedprimers$Location])
ordiellipse(fig1,groups=matchedprimers$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Fleece",col="grey25",lty=5)
ordiellipse(fig1,groups=matchedprimers$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Control",col="grey25")
ordiellipse(fig1,groups=matchedprimers$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Snowfence",col="grey25",lty=3)
ordiellipse(fig1,groups=matchedprimers$Location,kind="se", conf=0.95,lwd=2,show.groups="IN",col="blue")
ordiellipse(fig1,groups=matchedprimers$Location,kind="se", conf=0.95,lwd=2,show.groups="IV",col="forestgreen")
ordiellipse(fig1,groups=matchedprimers$Location,kind="se", conf=0.95,lwd=2,show.groups="O",col="red")
#legend("topright",lty=c(NA,NA,NA),pch=c(16,16,16),cex=0.9,col=c("blue","forestgreen","red"),lwd=2,seg.len=3,legend=c("Inner domain non-vegetated","Inner domain vegetated","Outer domain"))
plot(fitmds,col="black")






#### 4. Figure 4  ---- 
#### 4a. vegetation cover ####
#Caculate means 
meanpergroup<-aggregate(vegcover~treatment+sampling.point, FUN=mean, data=alldata)
#Calculate standard errors
sterrors<-aggregate(vegcover~treatment+sampling.point,FUN=se,data=alldata)
stats4 <- cbind(meanpergroup,sterrors$vegcover)
stats4 <- plyr::rename(stats4,c("sterrors$vegcover"="se"))

## correcting names of domains
stats4$sampling.point <- as.character(stats4$sampling.point)
stats4$sampling.point[stats4$sampling.point=="IDNV"] <- "Inner domain bare"
stats4$sampling.point[stats4$sampling.point=="IDV"] <- "Inner domain vegetated"
stats4$sampling.point[stats4$sampling.point=="OD"] <- "Outer domain"
stats4$sampling.point <- as.factor(stats4$sampling.point)

##make plot
bargraphvegcover<- ggplot(stats4,aes(x = treatment, y = vegcover,fill=treatment)) + 
  geom_bar(stat = "identity") + facet_grid(~sampling.point)+scale_fill_grey(start=0.2,end=0.6)+
  geom_errorbar(aes(ymin=vegcover-se, ymax=vegcover+se), width=.3,linetype=1)+
  theme(panel.background=element_blank(),
        strip.text.x=element_blank(),
        strip.background=element_blank(),
        axis.text.y=element_text(size=18, color="black"),
        axis.text.x=element_blank(),
        axis.title.y=element_text(size=18,vjust=1),
        panel.border=element_blank(),
        panel.grid=element_blank(),
        axis.line = element_line(),
        legend.position="none")+
  theme(axis.title.y=element_text(size=18),
        axis.title.x=element_blank())+
  ylab("Vegetation cover %")+scale_y_continuous(limits = c(0, 105))
#### 4b. SOM ####
#Caculate means 
meanpergroup<-aggregate(som~treatment+sampling.point, FUN=mean, data=alldata)
#Calculate standard errors
sterrors<-aggregate(som~treatment+sampling.point,FUN=se,data=alldata)
stats <- cbind(meanpergroup,sterrors$som)
stats <- plyr::rename(stats,c("sterrors$som"="se"))

# specify factors in dataframe and rename some locations for representation in the graph
stats$sampling.point <- as.character(stats$sampling.point)
stats$sampling.point[stats$sampling.point=="IDNV"] <- "Inner domain bare"
stats$sampling.point[stats$sampling.point=="IDV"] <- "Inner domain vegetated"
stats$sampling.point[stats$sampling.point=="OD"] <- "Outer domain"
stats$sampling.point <- as.factor(stats$sampling.point)

## make plot
bargraphsom <- ggplot(stats,aes(x = treatment, y = som, fill=treatment)) + 
  geom_bar(stat = "identity") + facet_grid(~sampling.point)+
  scale_fill_grey(start=0.2,end=0.6)+
  geom_errorbar(aes(ymin=som-se, ymax=som+se), width=.3,linetype=1)+
  theme(panel.background=element_blank(),
        strip.text.x=element_text(size=20,face=3),
        strip.background=element_blank(),
        axis.text.y=element_text(size=18, color="black"),
        axis.text.x=element_blank(),
        axis.title.y=element_text(size=18,vjust=1),
        panel.border=element_blank(),
        panel.grid=element_blank(),
        axis.line = element_line())+
  theme(axis.title.y=element_text(size=18),
        axis.title.x=element_blank(),
        legend.position="none")+
  ylab("SOM %")+scale_y_continuous(limits = c(0, 40))

#### 4c. bulk ####
## calculate means
meanpergroup<-aggregate(bulk~treatment+sampling.point, FUN=mean, data=alldata)
#Calculate standard errors
sterrors<-aggregate(bulk~treatment+sampling.point,FUN=se,data=alldata)
stats3 <- cbind(meanpergroup,sterrors$bulk)
stats3 <- plyr::rename(stats3,c("sterrors$bulk"="se"))

stats3$sampling.point <- as.character(stats3$sampling.point)
stats3$sampling.point[stats3$sampling.point=="IDNV"] <- "Inner domain bare"
stats3$sampling.point[stats3$sampling.point=="IDV"] <- "Inner domain vegetated"
stats3$sampling.point[stats3$sampling.point=="OD"] <- "Outer domain"
stats3$sampling.point <- as.factor(stats3$sampling.point)

## make plot
bargraphbulk <- ggplot(stats3,aes(x = treatment, y = bulk, fill=treatment)) + 
  geom_bar(stat = "identity") + facet_grid(~sampling.point)+ scale_fill_grey(start=0.2,end=0.6)+
  geom_errorbar(aes(ymin=bulk-se, ymax=bulk+se), width=.3,linetype=1)+
  theme(panel.background=element_blank(),
        strip.text.x=element_blank(),
        strip.background=element_blank(),
        axis.text.y=element_text(size=18, color="black"),
        axis.text.x=element_blank(),
        axis.title.y=element_text(size=18,vjust=1),
        panel.border=element_blank(),
        panel.grid=element_blank(),
        axis.line = element_line(),
        legend.position="none")+
  theme(axis.title.y=element_text(size=18),
        axis.title.x=element_blank())+
  ylab("Bulk g/cm3")+scale_y_continuous(limits = c(0, 1.7))

#### 4d. pH ####
### caluculate means
meanpergroup<-aggregate(pH~treatment+sampling.point, FUN=mean, data=alldata)
#Calculate standard errors
sterrors<-aggregate(pH~treatment+sampling.point,FUN=se,data=alldata)
stats5 <- cbind(meanpergroup,sterrors$pH)
stats5 <- plyr::rename(stats5,c("sterrors$pH"="se"))

## correcting names of domains
stats5$sampling.point <- as.character(stats5$sampling.point)
stats5$sampling.point[stats5$sampling.point=="IDNV"] <- "Inner domain bare"
stats5$sampling.point[stats5$sampling.point=="IDV"] <- "Inner domain vegetated"
stats5$sampling.point[stats5$sampling.point=="OD"] <- "Outer domain"
stats5$sampling.point <- as.factor(stats5$sampling.point)

##make plot
bargraphph<- ggplot(stats5,aes(x = treatment, y = pH,fill=treatment)) + 
  geom_bar(stat = "identity") + facet_grid(~sampling.point)+scale_fill_grey(start=0.2,end=0.6)+
  geom_errorbar(aes(ymin=pH-se, ymax=pH+se), width=.3,linetype=1)+
  theme(panel.background=element_blank(),
        strip.text.x=element_blank(),
        strip.background=element_blank(),
        axis.text.y=element_text(size=18, color="black"),
        axis.text.x=element_text(size=20, color="black"),
        axis.title.y=element_text(size=18,vjust=1),
        panel.border=element_blank(),
        panel.grid=element_blank(),
        axis.line = element_line(),
        legend.position="none")+
  theme(axis.title.y=element_text(size=18),
        axis.title.x=element_blank())+
  ylab("pH")+scale_y_continuous(limits = c(0, 6))


#### 4e. Soil moisture ####
#Caculate means 
meanpergroup<-aggregate(soil.moisture~treatment+sampling.point, FUN=mean, data=alldata)
#Calculate standard errors
sterrors<-aggregate(soil.moisture~treatment+sampling.point,FUN=se,data=alldata)
stats2 <- cbind(meanpergroup,sterrors$soil.moisture)
stats2 <- plyr::rename(stats2,c("sterrors$soil.moisture"="se"))

## correcting names of domains
stats2$sampling.point <- as.character(stats2$sampling.point)
stats2$sampling.point[stats2$sampling.point=="IDNV"] <- "Inner domain bare"
stats2$sampling.point[stats2$sampling.point=="IDV"] <- "Inner domain vegetated"
stats2$sampling.point[stats2$sampling.point=="OD"] <- "Outer domain"
stats2$sampling.point <- as.factor(stats2$sampling.point)

## make plot
bargraphsoilmoist <- ggplot(stats2,aes(x = treatment, y = soil.moisture,fill=treatment)) + 
  geom_bar(stat = "identity") + facet_grid(~sampling.point)+
  scale_fill_grey(start=0.2,end=0.6)+
  geom_errorbar(aes(ymin=soil.moisture-se, ymax=soil.moisture+se), width=.3,linetype=1)+
  theme(panel.background=element_blank(),
        strip.text.x=element_blank(),
        strip.background=element_blank(),
        axis.text.y=element_text(size=18, color="black"),
        axis.text.x=element_blank(),
        axis.title.y=element_text(size=18,vjust=1),
        panel.border=element_blank(),
        panel.grid=element_blank(),
        axis.line = element_line(),
        legend.position="none")+
  theme(axis.title.y=element_text(size=18),
        axis.title.x=element_blank())+
  ylab("Soil moisture ml/cm3")+scale_y_continuous(limits = c(0, 0.23))

g<-arrangeGrob(bargraphvegcover,bargraphsom,bargraphbulk,bargraphph,bargraphsoilmoist,ncol=1)
ggsave("Figure_4.pdf",dpi=600,width = 25, height = 60, units = "cm", g)

#### 5. Supplementary Figure S2 ----
x <- as.numeric(snow2013[1,4:10])
for(i in 2:nrow(snow2013))
{
  x <- c(x, as.numeric(snow2013[i,4:10]))
}
df.2013 <- data.frame(depth=x)
df.2013$plot <- as.vector(sapply(snow2013$plot, function(x) rep(x,7)))
df.2013$treatment <- c(rep("Control",42), rep("Fleece",42), rep("Snow",21))
df.2013$distance <- rep(c(0,50,100,150,200,250,300),15)

x <- as.numeric(snow2014_1[1,4:10])
for(i in 2:nrow(snow2014_1))
{
  x <- c(x, as.numeric(snow2014_1[i,4:10]))
}
df.2014_1 <- data.frame(depth=x)
df.2014_1$plot <- as.vector(sapply(snow2014_1$plot, function(x) rep(x,7)))
df.2014_1$treatment <- c(rep("Control",42), rep("Fleece",42), rep("Snow",21))
df.2014_1$distance <- rep(c(0,50,100,150,200,250,300),15)
# 2014_2
x <- as.numeric(snow2014_2[1,4:10])
for(i in 2:nrow(snow2014_2))
{
  x <- c(x, as.numeric(snow2014_2[i,4:10]))
}
df.2014_2 <- data.frame(depth=x)
df.2014_2$plot <- as.vector(sapply(snow2014_2$plot, function(x) rep(x,7)))
df.2014_2$treatment <- c(rep("Control",42), rep("Fleece",42), rep("Snow",21))
df.2014_2$distance <- rep(c(0,50,100,150,200,250,300),15)

df.2013$year <- factor("2013")
df.2014_1$year <- factor("2014a")
df.2014_2$year <- factor("2014b")
df.all <- rbind(df.2013, df.2014_1, df.2014_2)
lineplot.CI(distance, depth, treatment, data=df.all, col="black",pch=c(16,15,17),lty=c(1,2,3),
            ylab="Snow depth [cm]", xlab="Distance from plot west side [cm]", 
            ylim=c(0,65), cex.lab=1.6, cex.axis=1.4, cex.leg=1.6, x.leg=5.3, y.leg=60, fixed=T,
            err.width=.05, yaxt="n")
axis(2, las=2, cex.axis=1.4)


#### 6. Supplementary Figure S4 ----
# Subset metadata table for subsetted distance matrixes
met_deep<-subset(matchedprimers,rownames(matchedprimers) %in% rownames(mdsdeep$points))
all.equal(rownames(mdsdeep$points),as.character(met_deep$SampleID))
met_deep<-met_deep[match(rownames(mdsdeep$points),met_deep$SampleID),]
all.equal(rownames(mdsdeep$points),as.character(met_deep$SampleID))
met_surf<-subset(matchedprimers,rownames(matchedprimers) %in% rownames(mdssurf$points))
all.equal(rownames(mdssurf$points),as.character(met_surf$SampleID))

# Bacteria surface
fig1<-ordiplot(mdssurf,cex.axis=1.3,cex.lab=1.5)
points(mdssurf,pch=c(16,15,17)[met_surf$Treatment],cex=1.3,col=c("blue","forestgreen","red")[met_surf$Location])
ordiellipse(fig1,groups=met_surf$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Fleece",col="black",lty=5)
ordiellipse(fig1,groups=met_surf$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Control",col="black")
ordiellipse(fig1,groups=met_surf$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Snowfence",col="black",lty=3)
ordiellipse(fig1,groups=met_surf$Location,kind="se", conf=0.95,lwd=3,show.groups="IN",col="blue")
ordiellipse(fig1,groups=met_surf$Location,kind="se", conf=0.95,lwd=3,show.groups="IV",col="forestgreen")
ordiellipse(fig1,groups=met_surf$Location,kind="se", conf=0.95,lwd=3,show.groups="O",col="red")
legend("bottomleft",bty="n",box.col=NA,lty=c(1,5,3,NA,1,1,1),pch=c(16,15,17,16,16,16,16),col=c("black","black","black",NA,"blue","forestgreen","red"),lwd=2,seg.len=3,legend=c("Control","Fleece","Snow",NA,"Inner domain bare","Inner domain vegetated","Outer domain"))

# Bacteria deep
fig1<-ordiplot(mdsdeep,cex.axis=1.3,cex.lab=1.5)
points(mdsdeep,pch=c(16,15,17)[met_deep$Treatment],cex=1.3,col=c("blue","forestgreen","red")[met_deep$Location])
ordiellipse(fig1,groups=met_deep$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Fleece",col="black",lty=5)
ordiellipse(fig1,groups=met_deep$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Control",col="black")
ordiellipse(fig1,groups=met_deep$Treatment,kind="se", conf=0.95,lwd=2,show.groups="Snowfence",col="black",lty=3)
ordiellipse(fig1,groups=met_deep$Location,kind="se", conf=0.95,lwd=3,show.groups="IN",col="blue")
ordiellipse(fig1,groups=met_deep$Location,kind="se", conf=0.95,lwd=3,show.groups="IV",col="forestgreen")
ordiellipse(fig1,groups=met_deep$Location,kind="se", conf=0.95,lwd=3,show.groups="O",col="red")

#### 7. Supplementary Figure S5 #####
### Upper part: bacteria ----
alpha_div$Treatment<-Metadata_div$Treatment
alpha_div$Location<-Metadata_div$Location
alpha_div$Block<-Metadata_div$Block
alpha_div$Mod<-Metadata_div$Mod
levels(alpha_div$Location)<-c("Inner domain bare","Inner domain vegetated","Outer domain")
levels(alpha_div$Treatment)<-c("Control","Fleece","Snow")
alpha_div$Mod_f = factor(alpha_div$Mod, levels=c("Surface","Deep"))

ggplot(aes(x=Location,y=ace,color=Location),data=alpha_div)+
  theme_bw()+
  theme(axis.text.x=element_blank(),
        axis.ticks.x = element_blank())+
  stat_summary(fun.data=mean_se)+
  facet_grid(Mod_f~Treatment)+
  xlab("")+
  ylab("Abundance-based coverage estimator (ACE)")+
  guides(col=guide_legend("Sampling domain"))+
  scale_color_manual(values=c("blue","forestgreen","red"))

## Lower part: Collembola ----
alpha$treatment <- as.character(alpha$treatment)
alpha$treatment[alpha$treatment=="control"] <- "Control"
alpha$treatment[alpha$treatment=="fleece"] <- "Fleece"
alpha$treatment[alpha$treatment=="snow"] <- "Snow"

alpha$location <- as.character(alpha$location)
alpha$location[alpha$location=="IDNV"] <- "Inner domain bare"
alpha$location[alpha$location=="IDV"] <- "Inner domain vegetated"
alpha$location[alpha$location=="OD"] <- "Outer domain"

ggplot(aes(x=location,y=richness,color=location),data=alpha)+
  theme_bw()+
  theme(axis.text.x=element_blank(),
        axis.ticks.x = element_blank())+
  stat_summary(fun.data = mean_se)+
  facet_grid(~treatment)+
  xlab("")+
  ylab("Species richness")+
  guides(col=guide_legend("Sampling domain"))+
  scale_color_manual(values=c("blue","forestgreen","red"))

